export var validKey = true;
export var nested = {
	subKey: "ok"
};
export var array = [
	1,
	"2"
];
export default {
	validKey: validKey,
	"invalid-key": 1,
	nested: nested,
	array: array,
	"function": "not used",
	"null": null
};
